@@ -28,12 +28,12 @@ class GrantleeViewFormatter;
 class AKREGATOR_EXPORT DefaultCombinedViewFormatter : public ArticleFormatter
 {
 public:
-    explicit DefaultCombinedViewFormatter(const QString &grantleeDirectory, const QUrl &imageDir, QPaintDevice *device = nullptr);
+    explicit DefaultCombinedViewFormatter(const QString &grantleeDirectory, QPaintDevice *device = nullptr);
     ~DefaultCombinedViewFormatter() override;
 
-    QString formatArticles(const QVector<Article> &articles, IconOption option) const override;
+    Q_REQUIRED_RESULT QString formatArticles(const QVector<Article> &articles, IconOption option) const override;
 
-    QString formatSummary(TreeNode *node) const override;
+    Q_REQUIRED_RESULT QString formatSummary(TreeNode *node) const override;
 
 private:
     DefaultCombinedViewFormatter();
