@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
+  Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
@@ -24,8 +24,6 @@ using namespace Akregator;
 
 DownloadArticleJob::DownloadArticleJob(QObject *parent)
     : QObject(parent)
-    , mTemporaryFile(nullptr)
-    , mAttachmentTemporaryFile(nullptr)
 {
 }
 
